/*
   Copyright (c) 2004-2005 The University of Chicago, as Operator
   of Argonne National Laboratory.
*/
package gov.anl.aps.irmis.apps.component.cfw;

import java.net.URL;
import java.util.List;
import java.util.Set;
import java.util.Iterator;
import javax.swing.SwingUtilities;
import javax.swing.JDesktopPane;

// XAL framework stuff
import gov.sns.application.*;

// work queue support from concurrent.jar
import EDU.oswego.cs.dl.util.concurrent.QueuedExecutor;

// general app utilities
import gov.anl.aps.irmis.apps.SwingThreadWork;

// rdbCore imports
import gov.anl.aps.irmis.persistence.pv.IOCBootDAO;
import gov.anl.aps.irmis.persistence.pv.RecordDAO;
import gov.anl.aps.irmis.persistence.pv.FieldDAO;
import gov.anl.aps.irmis.persistence.pv.Record;
import gov.anl.aps.irmis.persistence.pv.RecordType;
import gov.anl.aps.irmis.persistence.pv.Field;
import gov.anl.aps.irmis.persistence.pv.FieldType;
import gov.anl.aps.irmis.persistence.DAOException;


/**
 * The primary controller class for IRMIS Component Viewer application.
 * Provides "action" methods to to query the IRMIS database for component
 * related data. These action methods are typically invoked by the 
 * <code>ComponentWindow</code>.
 * Any time-consuming activity should be queued up using the 
 * <code>queuedExecutor</code>, which is similar to the SwingWorker concept.
 */
public class ComponentDocument extends XalInternalDocument {

	/** The main data model of this application */
	private ComponentModel _model;

    /** 
     * Background work queue we use to handle lengthy logic (ie. sql queries). This
     * is a work queue backed by a single common background thread. It's important
     * to conduct most if not all sql activity on this thread, as the Hibernate
     * session is maintained in ThreadLocal storage, and therefore should only
     * exist on one thread to take advantage of Hibernate caching. The QueuedExecutor
     * class comes from the public domain concurrent.jar library, most of which
     * went into Sun's JDK 1.5 java.util.concurrent package. We're still on JDK1.4.
     */
	QueuedExecutor queuedExecutor = new QueuedExecutor();
	

	/** Create a new empty document */
    public ComponentDocument() {
        this(null);
        _model = new ComponentModel();
    }

	/** Create a new document from url */
    public ComponentDocument(final URL url) {
        //setSource(url);
        _model = new ComponentModel();

        // don't have anything here yet
    }

    public void saveDocumentAs(final URL url) {
        return;
    }

    /**
     * Specifies the document file suffixes supported by this document.
     * @return An array of file suffixes corresponding to writable files
     */
    public String[] writableDocumentTypes() {
        return new String[] {};
	}

    /**
	 * Overriding default window title to my liking.
     * @param newTitle The new title for this document.
     */
    public void setTitle( final String newTitle ) {
        String modifiedTitle = "Component Viewer" + newTitle;
		super.setTitle( modifiedTitle );
        _documentListenerProxy.titleChanged( this, title );
    }	
            
    /**
     * Make a main window by instantiating the my custom window.
     */
    public void makeMainWindow() {
        _mainWindow = new ComponentWindow(this);
    }


	/**
	 * Get the launch model which represents the main model of this document
	 * @return the main model of this document
	 */
	public ComponentModel getModel() {
		return _model;
	}

    private ComponentWindow myWindow() {
        return (ComponentWindow)_mainWindow;
    }
}
