# Schema for holding inventory of pv's in ioc's, as well as a
# record of ioc boots, and the file system resources (dbd, db files).

# ioc table stores master list of facility ioc's. must be manually
# pre-populated for pv crawler to work.

# Columns:
#   ioc_nm - ioc name
#   system - arbitrary string identifying ioc group membership (optional)
#   active - flag (0 or 1) indicating whether ioc considered active (used)
#   modified_date - time of row insert
#   modified_by - username or app name who performed insert

drop table if exists ioc;
create table ioc
  (
    ioc_id int not null primary key auto_increment,
    ioc_nm varchar(40),
    system varchar(20),
    active tinyint(1),
    modified_date timestamp,
    modified_by varchar(10)
  ) type=InnoDb;

# ioc_attr table holds an arbitrary set of attributes for each ioc,
#   such as contact phone number, or group membership (ie. linac).
#
drop table ioc_attr;
create table ioc_attr
  (
    ioc_attr_id int not null primary key auto_increment,
    ioc_id int,
    ioc_attr_type_id int,
    ioc_attr_value varchar(50)
  ) type=InnoDb;

# ioc_attr_type table enumerates the set of attributes that an ioc
#   can have.

drop table ioc_attr_type;
create table ioc_attr_type
  (
    ioc_attr_type_id int not null primary key auto_increment,
    ioc_attr_name varchar(50)
  ) type=InnoDb;

       
# ioc_boot table stores time-based record of ioc boot ocurrences

# Columns:
#   ioc_id - fk to ioc table
#   sys_boot_line - path of st.cmd file for this ioc
#   ioc_boot_date - time of ioc boot (as best we can determine)
#   current_load - flag (0 or 1) 1 if this ioc_boot record is the most recent
#                  ioc_boot record for the given ioc that has a set of records
#                  associated with it.
#   current_boot - flag (0 or 1) 1 if this ioc_boot record is just a record of
#                  a reboot, but does not have a set of records associated with it.
#   modified_date - time of row insert
#   modified_by - username or app name who performed insert

drop table ioc_boot;
# Note: change tinyint(1) to boolean when we move to MySQL 4.1.x
create table ioc_boot
  (
    ioc_boot_id int not null primary key auto_increment,
    ioc_id int,
    sys_boot_line varchar(127),
    ioc_boot_date timestamp,
    current_load tinyint(1),
    current_boot tinyint(1),
    modified_date timestamp,
    modified_by varchar(10)
  ) type=InnoDb;     

drop table ioc_error;
create table ioc_error
  (
    ioc_error_id int not null primary key auto_increment,
    ioc_boot_id int,
    ioc_error_num int
  ) type=InnoDb;

drop table ioc_resource;
create table ioc_resource
  (
    ioc_resource_id int not null primary key auto_increment,
    ioc_boot_id int,
    text_line varchar(255),
    load_order int,
    uri_id int,
    unreachable tinyint(1),
    subst_str varchar(255),
    ioc_resource_type_id int
  ) type=InnoDb;      

drop table rec;
create table rec
  (
    rec_id int not null primary key auto_increment,
    ioc_boot_id int,
    rec_nm varchar(128),
    rec_type_id int
  ) type=InnoDb;      

drop table fld;
create table fld
  (
    fld_id int not null primary key auto_increment,
    rec_id int,
    fld_type_id int,
    fld_val varchar(128),
    ioc_resource_id int 
  ) type=InnoDb;      

drop table rec_type;
create table rec_type
  (
    rec_type_id int not null primary key auto_increment,
    ioc_boot_id int,
    rec_type varchar(24),
    ioc_resource_id int
  ) type=InnoDb;      

drop table fld_type;
create table fld_type
  (
    fld_type_id int not null primary key auto_increment,
    rec_type_id int,
    fld_type varchar(24),
    dbd_type varchar(24),
    def_fld_val varchar(128)
  ) type=InnoDb;      

drop table rec_type_dev_sup;
create table rec_type_dev_sup
  (
    rec_type_dev_sup_id int not null primary key auto_increment,
    rec_type_id int,
    dtyp_str varchar(50),
    dev_sup_dset varchar(50),
    dev_sup_io_type varchar(50)
  ) type=InnoDb;


