/*
   Copyright (c) 2004-2005 The University of Chicago, as Operator
   of Argonne National Laboratory.
*/
package gov.anl.aps.irmis.persistence.pv;

import gov.anl.aps.irmis.persistence.HashCodeUtil;
import java.io.Serializable;
import java.util.Date;

/**
 * IRMIS business object that represents a single IOC Attribute type.
 * This class is mapped via hibernate almost one-to-one with IRMIS ioc_attr_type table.
 */
public class IOCAttributeType implements Serializable {

    private Long id;
    private String attributeName;

    /**
     * Constructor
     */
    public IOCAttributeType() {
    }

    /**
     * Get primary key.
     */
    public Long getId() {
        return this.id;
    }

    /**
     * Primary key. Not typically set explicitly by application code.
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * Get the attributes type.
     */
    public String getAttributeType() {
        return this.attributeName;
    }
    /**
     * Set the attributes type. 
     */    
    public void setAttributeType(String attributeName) {
        this.attributeName = attributeName;
    }

    public String toString() {
        return getId().toString() + ":" + getAttributeType();
    }

    /**
     * Custom equals which compares "business key" equality.
     */
    public boolean equals(Object other) {
        if (this==other) return true;
        if ( !(other instanceof IOCAttributeType) ) return false;
        final IOCAttributeType castOther = (IOCAttributeType) other;
        return this.getAttributeType().equals(castOther.getAttributeType());
    }

    /**
     * Custom hashCode computed on "business key" fields.
     */
    public int hashCode() {
        int result = HashCodeUtil.SEED;
        result = HashCodeUtil.hash(result, getAttributeType());
        return result;
    }

}
