/*
   Copyright (c) 2004-2005 The University of Chicago, as Operator
   of Argonne National Laboratory.
*/
package gov.anl.aps.irmis.persistence.pv;

import java.io.Serializable;
import java.util.Map;
import java.util.TreeMap;
import java.util.Iterator;

/**
 * Class to represent all known record type strings such as ai, mbbo, etc.
 * This is explicitly enumerated for the moment, but this class should probably
 * instantiate from a database table containing all known record types.
 */
public class RecordTypeEnum implements Serializable {

    static private Map recordTypes = new TreeMap();

    private String code;

    private RecordTypeEnum() {
    }

    private RecordTypeEnum(String recordType) {
        code = recordType;
        recordTypes.put(recordType, this);
    }

    public String getCode() {
        return code;
    }

    static public RecordTypeEnum find(String recordType) {
        return (RecordTypeEnum)recordTypes.get(recordType);
    }

    static public Iterator iterator() {
        // sort results
        return recordTypes.values().iterator();
    }

    static final RecordTypeEnum AB1771IFE = new RecordTypeEnum("ab1771IFE");
    static final RecordTypeEnum AB1771IX = new RecordTypeEnum("ab1771IX");
    static final RecordTypeEnum AB1771N = new RecordTypeEnum("ab1771N");
    static final RecordTypeEnum AB1791 = new RecordTypeEnum("ab1791");
    static final RecordTypeEnum ABDCM = new RecordTypeEnum("abDcm");
    static final RecordTypeEnum AI = new RecordTypeEnum("ai");

    static final RecordTypeEnum AO = new RecordTypeEnum("ao");
    static final RecordTypeEnum BEAMH = new RecordTypeEnum("beamh");
    static final RecordTypeEnum BEAMCHAN = new RecordTypeEnum("beamhchan");
    static final RecordTypeEnum BI = new RecordTypeEnum("bi");
    static final RecordTypeEnum BO = new RecordTypeEnum("bo");
    static final RecordTypeEnum BPM = new RecordTypeEnum("bpm");
    static final RecordTypeEnum CALC = new RecordTypeEnum("calc");
    static final RecordTypeEnum CALCOUT = new RecordTypeEnum("calcout");
    static final RecordTypeEnum CM = new RecordTypeEnum("cm");

    static final RecordTypeEnum COMPRESS = new RecordTypeEnum("compress");
    static final RecordTypeEnum DATALOG = new RecordTypeEnum("datalog");
    static final RecordTypeEnum DDLYPULSE = new RecordTypeEnum("ddlypulse");
    static final RecordTypeEnum DDLYPULSEVME = new RecordTypeEnum("ddlypulsevme");
    static final RecordTypeEnum DFANOUT = new RecordTypeEnum("dfanout");
    static final RecordTypeEnum DIGITAL = new RecordTypeEnum("digitel");
    static final RecordTypeEnum EG = new RecordTypeEnum("eg");
    static final RecordTypeEnum EGEVENT = new RecordTypeEnum("egevent");
    static final RecordTypeEnum ER = new RecordTypeEnum("er");

    static final RecordTypeEnum EREVENT = new RecordTypeEnum("erevent");
    static final RecordTypeEnum EVENT = new RecordTypeEnum("event");
    static final RecordTypeEnum FANOUT = new RecordTypeEnum("fanout");
    static final RecordTypeEnum FBUFFER = new RecordTypeEnum("fbuffer");
    static final RecordTypeEnum GP307 = new RecordTypeEnum("gp307");
    static final RecordTypeEnum GPIB = new RecordTypeEnum("gpib");
    static final RecordTypeEnum HISTOGRAM = new RecordTypeEnum("histogram");
    static final RecordTypeEnum IMAGE = new RecordTypeEnum("image");
    static final RecordTypeEnum IQ = new RecordTypeEnum("iq");
    static final RecordTypeEnum LONGIN = new RecordTypeEnum("longin");
    static final RecordTypeEnum LONGOUT = new RecordTypeEnum("longout");
    static final RecordTypeEnum MBBI = new RecordTypeEnum("mbbi");
    static final RecordTypeEnum MBBIDIRECT = new RecordTypeEnum("mbbiDirect");
    static final RecordTypeEnum MBBO = new RecordTypeEnum("mbbo");

    static final RecordTypeEnum MBBODIRECT = new RecordTypeEnum("mbboDirect");
    static final RecordTypeEnum MEMSCAN = new RecordTypeEnum("memscan");
    static final RecordTypeEnum MOTOR = new RecordTypeEnum("motor");
    static final RecordTypeEnum MSBPM = new RecordTypeEnum("msbpm");
    static final RecordTypeEnum MSBPMX = new RecordTypeEnum("msbpmX");
    static final RecordTypeEnum PULSEDELAY = new RecordTypeEnum("pulseDelay");
    static final RecordTypeEnum PULSETRAIN = new RecordTypeEnum("pulseTrain");
    static final RecordTypeEnum RF = new RecordTypeEnum("rf");
    static final RecordTypeEnum RT = new RecordTypeEnum("rt");

    static final RecordTypeEnum RUNCONTROL = new RecordTypeEnum("runcontrol");
    static final RecordTypeEnum SATRGA = new RecordTypeEnum("satRga");
    static final RecordTypeEnum SCALCOUT = new RecordTypeEnum("scalcout");
    static final RecordTypeEnum SCALER = new RecordTypeEnum("scaler");
    static final RecordTypeEnum SCAN = new RecordTypeEnum("scan");
    static final RecordTypeEnum SDDSLAUNCH = new RecordTypeEnum("sddsLaunch");
    static final RecordTypeEnum SDDSLAUNCH2 = new RecordTypeEnum("sddsLaunch2");
    static final RecordTypeEnum SDDSLAUNCH3 = new RecordTypeEnum("sddsLaunch3");
    static final RecordTypeEnum SEL = new RecordTypeEnum("sel");

    static final RecordTypeEnum SEQ = new RecordTypeEnum("seq");
    static final RecordTypeEnum SERIAL = new RecordTypeEnum("serial");
    static final RecordTypeEnum STATUS = new RecordTypeEnum("status");
    static final RecordTypeEnum STRINGIN = new RecordTypeEnum("stringin");
    static final RecordTypeEnum STRINGOUT = new RecordTypeEnum("stringout");
    static final RecordTypeEnum SUB = new RecordTypeEnum("sub");
    static final RecordTypeEnum SUBARRAY = new RecordTypeEnum("subArray");
    static final RecordTypeEnum TIMER = new RecordTypeEnum("timer");
    static final RecordTypeEnum TRANSFORM = new RecordTypeEnum("transform");

    static final RecordTypeEnum VACSCAN = new RecordTypeEnum("vacScan");
    static final RecordTypeEnum WAIT = new RecordTypeEnum("wait");
    static final RecordTypeEnum WAVEFORM = new RecordTypeEnum("waveform");
}
