package gov.anl.aps.irmis.persistence.test;

import java.util.Iterator;
import java.util.List;
import java.util.Set;

import gov.anl.aps.irmis.persistence.HibernateUtil;
import gov.anl.aps.irmis.persistence.DAOException;
import gov.anl.aps.irmis.persistence.pv.RecordType;
import gov.anl.aps.irmis.persistence.pv.Record;
import gov.anl.aps.irmis.persistence.pv.Field;
import gov.anl.aps.irmis.persistence.pv.FieldType;
import gov.anl.aps.irmis.persistence.pv.IOCBoot;
import gov.anl.aps.irmis.persistence.pv.IOCBootDAO;
import gov.anl.aps.irmis.persistence.pv.RecordDAO;
import gov.anl.aps.irmis.persistence.pv.RecordTypeDAO;
import gov.anl.aps.irmis.persistence.pv.FieldDAO;

import junit.framework.Assert;
import junit.framework.TestCase;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
   Test of efficient loading of a set of fields for a given record. This
   test grabs the db defined fields, as well as the record type defined
   fields.
*/

public class FieldTest extends TestCase {

    static Log log = LogFactory.getLog(FieldTest.class.getName());
    RecordDAO rDAO = null;
    IOCBootDAO ibDAO = null;
    FieldDAO fDAO = null;
    RecordTypeDAO rtDAO = null;

    public FieldTest(String name) {
        super(name);
        try {
            rDAO = new RecordDAO();
            ibDAO = new IOCBootDAO();
            fDAO = new FieldDAO();
            rtDAO = new RecordTypeDAO();
        } catch (DAOException de) {}
    }

    /**
       Selects all fields for a given record, including those defined
       by the record type.
    */
    public void testField() {
        List recordList = null;
        try {
            IOCBoot ib = ibDAO.findByIocName("iocpar02");
            rDAO.addBootIdConstraint(ib.getId());
            rDAO.setRecordNameGlobConstraint("P:Q2:OutVoltageAI");
            recordList = rDAO.findByConstraints();
            if (recordList != null) {
                if (recordList.size() != 1)
                    Assert.fail("Got back something other than 1 record");
                Iterator rIt = recordList.iterator();
                if (rIt.hasNext()) {
                    Record rec = (Record)rIt.next();
                    log.info("rec name:"+rec.getRecordName()+
                             " type:"+ rec.getRecordType().getRecordType());

                    // bring in fields/field type subgraph here
                    fDAO.findByRecordId(rec.getId());
                    
                    // iterator over fields to show field types for this record
                    Iterator fIt = rec.getFields().iterator();
                    while (fIt.hasNext()) {
                        Field field = (Field)fIt.next();
                        log.info("  db defined field name: "+field.getFieldType().getFieldType());
                    }

                    // bring in field types subgraph for given record type
                    rtDAO.findByRecordTypeId(rec.getRecordType().getId());
                    
                    // show any field types that aren't already shown above
                    Iterator ftIt = rec.getRecordType().getFieldTypes().iterator();
                    while (ftIt.hasNext()) {
                        FieldType fieldType = (FieldType)ftIt.next();
                        fIt = rec.getFields().iterator();
                        boolean found = false;
                        while (fIt.hasNext()) {
                            Field field = (Field)fIt.next();
                            if (field.getFieldType().getFieldType()
                                .equals(fieldType.getFieldType()))
                                found = true;
                        }
                        if (!found) 
                            log.info(" dbd defined field name: "+fieldType.getFieldType());
                    }
                }

            } else {
                Assert.fail("Unable to locate records");
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            Assert.fail(e.getMessage());
        }
        finally {
            HibernateUtil.closeSession();
        }
    }

}
