package gov.anl.aps.irmis.persistence.test;

import java.util.Iterator;
import java.util.List;
import java.util.Set;

import gov.anl.aps.irmis.persistence.HibernateUtil;
import gov.anl.aps.irmis.persistence.DAOException;
import gov.anl.aps.irmis.persistence.pv.IOC;
import gov.anl.aps.irmis.persistence.pv.IOCBoot;
import gov.anl.aps.irmis.persistence.pv.IOCResource;
import gov.anl.aps.irmis.persistence.pv.Record;
import gov.anl.aps.irmis.persistence.pv.RecordType;
import gov.anl.aps.irmis.persistence.pv.IOCBootDAO;
import gov.anl.aps.irmis.persistence.pv.IOCResourceDAO;
import gov.anl.aps.irmis.persistence.pv.RecordDAO;

import junit.framework.Assert;
import junit.framework.TestCase;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
   Test of efficient loading of a set of records.
*/

public class RecordTest extends TestCase {

    static Log log = LogFactory.getLog(RecordTest.class.getName());
    RecordDAO rDAO = null;
    IOCBootDAO ibDAO = null;

    public RecordTest(String name) {
        super(name);
        try {
            rDAO = new RecordDAO();
            ibDAO = new IOCBootDAO();
        } catch (DAOException de) {}
    }

    /**
       Selects a subset of records and record type objects based on a
       variety of query criteria.
    */
    public void testRecord() {
        List recordList = null;
        try {
            IOCBoot ib = ibDAO.findByIocName("iocpar02");
            rDAO.addBootIdConstraint(ib.getId());
            rDAO.addRecordTypeConstraint("ai");
            rDAO.setRecordNameGlobConstraint("*Voltage*");
            rDAO.addFieldIocResourceIdConstraint(new Long(2780));
            rDAO.setFieldNameGlobConstraint("INP");
            rDAO.setFieldValueGlobConstraint("#L0 N5 P4 S2 @");
            recordList = rDAO.findByConstraints();
            if (recordList != null) {
                Iterator rIt = recordList.iterator();
                while (rIt.hasNext()) {
                    Record rec = (Record)rIt.next();
                    log.info("rec name:"+rec.getRecordName()+
                             " type:"+ rec.getRecordType().getRecordType());
                }

            } else {
                Assert.fail("Unable to locate records");
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            Assert.fail(e.getMessage());
        }
        finally {
            HibernateUtil.closeSession();
        }
    }

}
